==> fhcore-libs-0.2.5.4.tar.gz: fhcore-libs-0.2.5.4/fhcore/apps/facebook/managers.py <==
# -*- coding: utf-8 -*-
""" Frankhood >  apps.facebook.game.managers by Frankhood
    @author: Frankhood Business Solutions
    @author: Gaetano D'Onghia
"""
from __future__ import absolute_import, print_function, unicode_literals

import datetime

from django.db import models
from django.utils.encoding import python_2_unicode_compatible
from .settings import FB_PLAYER_TYPE, SITE_PLAYER_TYPE


class PlayerManager(models.Manager):
    
        
    def get_or_create_from_facebook(self, data, user=None):
        try:
            return (self.get(id_attribute=data.get('id'), type=FB_PLAYER_TYPE,),False)
        except self.model.DoesNotExist:
            return (self.create_from_facebook(data, user), True)
    
    def get_from_facebook(self, data, user=None):
        try:
            return self.get(id_attribute=data.get('id'), type=FB_PLAYER_TYPE,)
        except self.model.DoesNotExist:
            return None
    
    
    def create_from_facebook(self, data, user=None):
        try:
            _full_name = "%s %s" % (data.get('first_name', ''), data.get('last_name', ''))
            # logger.info("utente facebook : %s" %(_full_name,))
        except Exception as ex:
            # logger.error("errore inatteso con nome e cognome dell'utente facebook")
            _full_name = ""
        return self.create(
            username=data.get('username', _full_name),
            first_name = data.get('first_name', ''),
            last_name = data.get('last_name', ''),
            email=data.get('email', ""),
            birthdate=datetime.datetime.strptime(data.get('birthday'), '%m/%d/%Y') if data.get('birthday') else None,
            type=FB_PLAYER_TYPE,
            id_attribute=data.get('id'),
            user=user,
            extra_data=data,  # json.dumps(data),
        )
            
    def create_from_site(self, user):
        raise NotImplementedError()
    
    def get_fb_users(self):
        queryset = self.get_query_set()
        return queryset.filter(type=FB_PLAYER_TYPE)
    
    def get_site_users(self):
        queryset = self.get_query_set()
        return queryset.filter(type=SITE_PLAYER_TYPE)

==> fhcore-libs-0.2.6.2.tar.gz: fhcore-libs-0.2.6.2/fhcore/apps/facebook/managers.py <==
# -*- coding: utf-8 -*-
""" Frankhood >  apps.facebook.game.managers by Frankhood
    @author: Frankhood Business Solutions
    @author: Gaetano D'Onghia
"""
from __future__ import absolute_import, print_function, unicode_literals

import datetime
import logging
import six

from django.db import models
from django.utils.encoding import python_2_unicode_compatible
from .settings import FB_PLAYER_TYPE, SITE_PLAYER_TYPE

logger = logging.getLogger('project')

class PlayerManager(models.Manager):
    
        
    def get_or_create_from_facebook(self, data, user=None):
        try:
            return (self.get(id_attribute=data.get('id'), type=FB_PLAYER_TYPE,),False)
        except self.model.DoesNotExist:
            return (self.create_from_facebook(data, user), True)
    
    def get_from_facebook(self, data, user=None):
        try:
            return self.get(id_attribute=data.get('id'), type=FB_PLAYER_TYPE,)
        except self.model.DoesNotExist:
            return None
    
    
    def create_from_facebook(self, data, user=None):
        try:
            _full_name = "%s %s" % (data.get('first_name', ''), data.get('last_name', ''))
            # logger.info("utente facebook : %s" %(_full_name,))
        except Exception as ex:
            # logger.error("errore inatteso con nome e cognome dell'utente facebook")
            _full_name = ""
        _birthdate = data.get('birthdate', None)
        if _birthdate:
            if not isinstance(_birthdate, datetime.date):
                if isinstance(_birthdate, six.string_types):
                    _birthdate = datetime.datetime.strptime(_birthdate, '%m/%d/%Y')
                if isinstance(_birthdate, datetime.date):
                    _birthdate = datetime.date(_birthdate.year,_birthdate.month,_birthdate.day)
        return self.create(
            username=data.get('username', _full_name),
            first_name = data.get('first_name', ''),
            last_name = data.get('last_name', ''),
            email=data.get('email', ""),
            birthdate=_birthdate,#datetime.datetime.strptime(data.get('birthday'), '%m/%d/%Y') if data.get('birthday') else None,
            type=FB_PLAYER_TYPE,
            id_attribute=data.get('id'),
            user=user,
            extra_data=data,  # json.dumps(data),
        )
            
    def create_from_site(self, user):
        raise NotImplementedError()
    
    def get_fb_users(self):
        queryset = self.get_query_set()
        return queryset.filter(type=FB_PLAYER_TYPE)
    
    def get_site_users(self):
        queryset = self.get_query_set()
        return queryset.filter(type=SITE_PLAYER_TYPE)
